==> haskell-file-embed-0.0.11.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.11.1
id: file-embed-0.0.11.1-1DkjC7VmQhQFLvxtpUIE3o
key: file-embed-0.0.11.1-1DkjC7VmQhQFLvxtpUIE3o
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.
category: Data
abi: fcd7d45569ba8e9cd0db38f8f6fa6e62
exposed: True
exposed-modules:
    Data.FileEmbed
import-dirs: /usr/lib/ghc-8.6.5/site-local/file-embed-0.0.11.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/file-embed-0.0.11.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/file-embed-0.0.11.1
hs-libraries: HSfile-embed-0.0.11.1-1DkjC7VmQhQFLvxtpUIE3o
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-file-embed-0.0.11-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.11
id: file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
key: file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.
category: Data
abi: c0b92ef9004fb6a37996c7e930c62ea3
exposed: True
exposed-modules:
    Data.FileEmbed
import-dirs: /usr/lib/ghc-8.6.1/site-local/file-embed-0.0.11
library-dirs: /usr/lib/ghc-8.6.1/site-local/file-embed-0.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/file-embed-0.0.11
hs-libraries: HSfile-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    filepath-1.4.2.1 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
